@@ -77,7 +77,7 @@ def evaluate_model(
 
         metadata_obj = {
             'sample_id': sample.sample_id,
-            'source_class': sample.source_class,
+            'source_class': sample.source_class.dict(),
             'elapsed_sec': time_total
         }
 
